# Une attaque par rançongiciel

L'attaque par rançongiciel, c'est une prise d'otage de données personnelles. Pour ce faire, ce logiciel va les chiffrer et ensuite afficher un message qui demande une rançon. Il y aura la plupart du temps une promesse de déchiffrer les données dans celui-ci.

Les pirates exigeront la somme due sous la forme de cryptomonnaie. Dans tous les cas, les autorités recommandent de ne jamais la payer.

![](chapitre-01-rancongiciel.png)

## Comment éviter cette histoire d'horreur?

### Développer une stratégie de sauvegarde efficace

Un système infecté par un rançongiciel est souvent cassé et devra être entièrement formaté. C'est pourquoi il est important de sauvegarder nos fichiers sur au moins deux supports différents :

- En ligne, sur un service infonuagique protégée par la cryptographie. L'outil [Borg](https://borgbackup.readthedocs.io/en/stable/), que nous recommandons, permet d'appliquer cette stratégie.
- Une copie physique sur un appareil de stockage tel qu'un disque dur portatif, une clé USB ou un autre ordinateur.

Pour faciliter cette tâche, nous suggérons le logiciel rsync. Pour avoir un aperçu de son utilisation, notre guide de juillet 2021, Partir en vacances l’esprit tranquille, propose un survol de cet outil. Vous pouvez l'obtenir à cette adresse : [https://jevalide.ca/2021/07/27/guide-pratique-partir-en-vacances-lesprit-tranquille/](https://jevalide.ca/2021/07/27/guide-pratique-partir-en-vacances-lesprit-tranquille/).

Une sauvegarde peut avoir été contaminée par un rançongiciel détecté tardivement. Pour contrer ce risque, nous recommandons de prévoir, en complément, une méthode incrémentale. Cette dernière conservera automatiquement une copie des versions antérieures des fichiers.

Assurez-vous de vous exercer régulièrement à la restauration de vos sauvegardes et de mettre en place une procédure simple à suivre. Si un incident survient, vous aurez bien d'autres soucis que vous remémorer cette procédure!

Un outil de collaboration tel que [Nextcloud](https://docs.nextcloud.com/server/latest/user_manual/en/files/version_control.html), permet de préserver plusieurs versions des fichiers de manière transparente. Sans être logiciel de sauvegarde, il peut être un maillon important dans la chaine de sécurisation.

Afin de limiter l'exposition à des données personnelles, essayez de les garder le moins longtemps possible sur votre ordinateur de travail. Préférez toujours un support déconnecté pour celles-ci, comme un disque dur ou une clé USB. Deux copies valent mieux qu'une dans ce cas!

Pour avoir plus de détails sur les différentes stratégies, nous vous invitons à consulter le guide intitulé **Les 3 types de sauvegardes** publié en aout 2021 à cette adresse : [https://jevalide.ca/2021/08/09/les-3-types-de-sauvegardes-guide-pdf-aout-2021/](https://jevalide.ca/2021/08/09/les-3-types-de-sauvegardes-guide-pdf-aout-2021/)

### Éviter les fichiers et liens suspects

Plusieurs types de contenus peuvent être suspects, tout particulièrement les liens et les pièces jointes dans les courriels et sur les sites Internet à réputation faible.

Un programme de sensibilisation aux courriels douteux est une bonne première étape, s'il est bien fait. Les groupes cybercriminels utilisent maintenant des techniques sophistiquées, alors les campagnes improvisées avec des courriels factices pleins de fautes d'orthographe et affichant un mauvais logo ne sont plus suffisantes pour des fins de dissuasion. Il faut réussir à prendre au piège le plus de notre personnel possible avec du réalisme pour avoir un impact.

Privilégiez, dans vos communications avec la clientèle et les entreprises, des contenus simples, en texte seulement, et évitez en tout temps les pièces jointes qui peuvent inclure du code exécutable, comme les fichiers de type Office. 

Dans tous les cas, n'ouvrez jamais de ces fichiers reçus par courriel qui proviennent d'une source externe, même si c'est un de vos contacts. Préférez utiliser un système de partage convenu à l'avance.

### Valider l'authenticité et l'intégrité des fichiers exécutables téléchargés

Lorsque vous devez ouvrir un fichier exécutable téléchargé de l'externe, assurez-vous de valider les sommes de contrôle de celui-ci. Ceci peut être réalisé avec l'utilitaire `shasum`, sur Linux et macOS, depuis le terminal.

```{bash}
shasum -a 1 <fichier>
```

Sur Windows, vous utilisez le logiciel `certutil` comme suit, depuis l'invite de commandes ou PowerShell.

```{powershell}
certutil -hashfile <fichier> SHA1
```

Évitez d'ouvrir des fichiers exécutables qui ne possèdent pas ces sommes de contrôle. C'est souvent signe que c'est un logiciel amateur qui n'est probablement pas sécurisé adéquatement.

### Effectuer la mise à jour périodique de tous ses logiciels et appareils

Nous ne pourrons jamais autant le répéter! Un des meilleurs moyens de garder son poste ou ses serveurs en sécurité, c'est de faire les mises à jour le plus fréquemment possible. Idéalement, celles-ci sont effectuées tous les jours. Dans le pire des cas, vous devriez le faire mensuellement.

Une règle d'or : aucun système qui n'a pas été mis à jour depuis plus d'un mois ne devrait se connecter à Internet. Point!

Sur Windows, en plus des correctifs du système, avec Windows Update, il faut faire le tour de chacun des logiciels installés. Heureusement, de plus en plus proposent de vérifier la présence de nouvelles versions lors de leur ouverture. Si cette option est disponible, activez-là!

### Utiliser des mots de passe robustes et uniques

Un mot de passe robuste n'est pas composé seulement de mots du dictionnaire et de chiffres. Il est unique et ne devrait être utilisé qu'une fois, pour un compte.

Il peut être difficile de retenir plusieurs mots de passe. Cependant, il existe maintenant des logiciels qui s'occupent de les gérer à notre place. Ils permettent même d'en générer des nouveaux. Un de ceux-ci est [Bitwarden](https://bitwarden.com/), un logiciel libre qui offre aussi un service gratuit en ligne. Ce logiciel propose des applications client sur toutes les plateformes et il est très convivial.

### Utiliser l'authentification à facteurs multiples

L'authentification à facteurs multiples permet d'éviter à quelqu'un qui aurait accès à votre mot de passe de se connecter sans pouvoir contrôler un autre élément. Il faut la privilégier sur tous les comptes en ligne où cette option est disponible.

Cette vérification peut être biométrique, avec une empreinte digitale, par un SMS ou avec une appli mobile de génération de mots de passe à usage unique basés sur le temps (Time-based one-time password, TOTP). [FreeOTP+](https://f-droid.org/en/packages/org.liberty.android.freeotpplus/) pour Android facilite cette tâche. De plus, il est possible d'effectuer une sauvegarde de celle-ci vers un autre appareil.
Sur iOS, [FreeOTP Authenticator](https://apps.apple.com/in/app/freeotp-authenticator/id872559395), une version antérieure, fait un travail similaire.

Il existe aussi des clés physiques, telles que la [Yubikey](https://www.yubico.com/?lang=fr), qui permettent d'augmenter la fluidité de l'expérience utilisateur.

### Activer le pare-feu de son ordinateur et de son routeur

Le pare-feu est un système qui permet d'ouvrir et de fermer des ports, c'est à dire des adresses pour faire entrer ou sortir de l'information entre votre ordinateur et un réseau informatique. Plus il y en a d'ouverts, plus il y a d’occasions pour qu'un logiciel malveillant pénètre dans votre poste de travail. C'est donc une bonne pratique de laisser passer seulement ce qui est absolument requis.

Sur Windows, vous accédez aux paramètres du pare-feu Defender en utilisant la commande suivante dans le navigateur Edge

```
ms-settings:windowsdefender
```

Windows vous suggèrera fortement de créer un compte OneDrive pour augmenter la sécurité. Mais, sachez que vous pouvez tout autant utiliser Nextcloud sur votre propre serveur privé sans avoir à payer de licence mensuelle dispendieuse. Vérifiez surtout que les autres options affichées sont activées.

Windows est un système intrusif qui communique énormément avec Microsoft, donc beaucoup de ports sont ouverts par défaut. Il peut être difficile de déterminer lesquels peuvent être fermés sans une expertise en administration Windows. Nous pouvons tout de même obtenir un aperçu en cliquant sur **Paramètres avancés** dans la fenêtre du pare-feu.

![](images/chapitre-01-parefeu-windows.png)

Sur macOS, le système inclut son propre pare-feu configurable depuis une interface graphique. Depuis les options, il est possible de bloquer toutes les connexions entrantes.

![](images/chapitre-01-parefeu-macos.png)

Sur Linux, le pare-feu par défaut est `iptables`. Il requiert une certaine expertise pour être configuré adéquatement. Heureusement, le logiciel `ufw` (Uncomplicated firewall) permet de simplifier la tâche. Pour l'activer, il suffit généralement d'exécuter cette commande :

```bash
sudo systemctl enable ufw
```

Pour nous assurer qu'il est activé, nous consultons le statut détaillé

```bash
sudo ufw status verbose
```

Ce qui devrait produire une sortie comme suit :

```plain
Status: active
Logging: on (low)
Default: deny (incoming), allow (outgoing), disabled (routed)
New profiles: skip
```

Ensuite, pour ouvrir les ports, nous utilisons le numéro ou le nom du service, tel que listé dans le fichier `/etc/services`.

## Trop tard... Quoi faire, maintenant?

### Couper l'accès au réseau

La première chose à faire, lors de toute détection d'attaque par rançongiciel ou de comportement suspect, comme la disparition de fichiers, est de couper l'accès au réseau. Commencez par déconnecter le câble et éteindre le wifi en débranchant le routeur. Sinon, il faut le fermer depuis son interface graphique, ce qui peut être ardu en entreprise.

### Aviser les autorités

Si vous recevez une demande de rançon, capturez l'écran avec votre mobile ou un appareil photo. Ne payez rien. Communiquez avec la police et une ou un spécialiste en cybersécurité. Ces derniers voudront probablement accéder à vos systèmes pour effectuer une analyse en criminalistique numérique. Il sera possible de restaurer les fichiers chiffrés, si le rançongiciel utilisé a été décodé.

### Formater le système infecté

Une fois qu'un système infecté a été neutralisé, il sera possible de le réinstaller. Dans ce cas, il est préférable de formater les disques avec une méthode de remplissage aléatoire. Il faut tout de même s'assurer que le rançongiciel ne s'est pas installé dans une des parties critiques du système, tel que le gestionnaire d'amorçage. Pour ce faire, nous devrons attendre les résultats de l'enquête en criminalistique numérique. 

### Effectuer une restauration

Localisez votre sauvegarde la plus récente et planifiez une restauration de celle-ci sur un autre réseau informatique que celui qui a été infecté, afin de, par exemple, publier en ligne un site web le plus rapidement possible. Ce peut être l'occasion de louer un serveur infonuagique temporaire pour se remettre sur pied.

Avec Windows, ça peut être difficile de reproduire un système sur une autre machine. Nous voudrons alors utiliser, au besoin, la fonction intégrée, qui se nomme le point de restauration. Elle est disponible depuis les Propriétés système, dans la section Protection du système.

![](images/chapitre-01-restauration-windows.png)

